Perpustakaan # polah

Π_172_ Π_171_

## 🌍 Aya basa

Pychelper nawiskeun terjemahan anu diwangun pikeun dugi ka ** 131 basa ** kaasup:

Π_170_ Π_169_ Π_168_ Π_167_ [![sv](https://img.shields.io/badge/lang-sv-blue.svg)](readme/README.sv.md) [![sv](https://img.shields.io/badge/lang-sv-blue.svg)](readme/README.sv.md) [![sv](https://img.shields.io/badge/lang-sv-blue.svg)](readme/README.sv.md) [![sv](https://img.shields.io/badge/lang-sv-blue.svg)](readme/README.sv.md)  
Π_160_ Π_159_ Π_158_ Π_157_ [![bm](https://img.shields.io/badge/lang-bm-darkgreen.svg)](readme/README.bm.md) Π_155.. [![bm](https://img.shields.io/badge/lang-bm-darkgreen.svg)](readme/README.bm.md) Π_155.  
Π_150_ [![be](https://img.shields.io/badge/lang-be-darkblue.svg)](readme/README.be.md) Π_148_ [![bho](https://img.shields.io/badge/lang-bho-orange.svg)](readme/README.bho.md) Π_141_ π_ [![co](https://img.shields.io/badge/lang-co-green.svg)](readme/README.co.md) Π_141_ [![co](https://img.shields.io/badge/lang-co-green.svg)](readme/README.co.md)  
Π_140_ [![cs](https://img.shields.io/badge/lang-cs-red.svg)](readme/README.cs.md) Π_138_ [![dv](https://img.shields.io/badge/lang-dv-orange.svg)](readme/README.dv.md) [![nl](https://img.shields.io/badge/lang-nl-orange.svg)](readme/README.nl.md) Π_135_ Π13_ [![tl](https://img.shields.io/badge/lang-tl-purple.svg)](readme/README.tl.md)  
Π_130_ [![fy](https://img.shields.io/badge/lang-fy-orange.svg)](readme/README.fy.md) Π_128_ Π_127_ Π_121_ Π_121_ Π12_ [![haw](https://img.shields.io/badge/lang-haw-red.svg)](readme/README.haw.md) [![haw](https://img.shields.io/badge/lang-haw-red.svg)](readme/README.haw.md) [![haw](https://img.shields.io/badge/lang-haw-red.svg)](readme/README.haw.md)  
Π_120_ Π_119_ Π_118_ [![hu](https://img.shields.io/badge/lang-hu-blue.svg)](readme/README.hu.md) [![is](https://img.shields.io/badge/lang-is-red.svg)](readme/README.is.md) [![ga](https://img.shields.io/badge/lang-ga-blue.svg)](readme/README.ga.md) [![ga](https://img.shields.io/badge/lang-ga-blue.svg)](readme/README.ga.md) Π11_  
Π_110_ [![kk](https://img.shields.io/badge/lang-kk-orange.svg)](readme/README.kk.md) Π_108_ Π_10_ Π_10. Π10  
Π_100_ Π_99_ Π_98_ Π_97_ [![lt](https://img.shields.io/badge/lang-lt-red.svg)](readme/README.lt.md) [![mg](https://img.shields.io/badge/lang-mg-red.svg)](readme/README.mg.md) Π_91_ π_  
Π_90_ [![ml](https://img.shields.io/badge/lang-ml-orange.svg)](readme/README.ml.md) Π_88_ Π_87_ [![mr](https://img.shields.io/badge/lang-mr-red.svg)](readme/README.mr.md) [![or](https://img.shields.io/badge/lang-or-purple.svg)](readme/README.or.md) π_ Π10_ Π_81_ π  
Π_79_ Π_78_ Π_77_ Π_76_ Π_75_ Π71_ Π_71_ Π_71_ π_  
Π_68_ Π_67_ [![sk](https://img.shields.io/badge/lang-sk-red.svg)](readme/README.sk.md) Π_65_ Π_64_ Π53_ Π_69_ π_ Π58_ π_  
Π_57_ Π56_ Π_55_ Π_54_ Π_53_ Python. π_ Π_47_ Π_47_  
Π_46_ Π_45_ Π_44_ Π_43_

---


## 🚀 instalasi

Pasang ti PYPI:

Π_42_

---

## 📖 📖

** Pysickper ** nyaéta lawan anth_41_ ivalkit pikeun langkung gampang langkung resep Anetkeun Andress, visualisasi, operasi statistik, sareng utilitas damelan **.  
Éta ngahijikeun mulekak, panalungtikan, sareng proyék profésional, ngalaan anjeun pikeun difoto tinimbang wawasan tinimbang mempur.

Kauntungan konci:
- 🧮 Diborak ** statistik sareng utilitas matematika ** 
- 📊 anu gampang-pindah * Fisualisasi visualisasi data **
- 🗂 Handy ** File sareng milarian ** 
- 🔍 ** sintaksis validasi ** pikeun file Π_40_
- 🌍 ** dukungan kerja
- 🚀 optimalan pikeun ** prototyping gancang ** sareng ** pendidikan ** 

---

# # Fitur konci

### visualisasi data
- bar bagan: horisontal & nangtung Π_39_  
- Plot Distribusional: Sistimnams (`histo`), Témbak Box Π_37_, Plot KD Π_36_  
- plot komparatif: biola, ngagimbung, plot strip  
- Analisis korélasi: Hemmmaps Π_35_, plots (`scatter`)  
- visualisasi canggih: plot pasangan, plot gabungan, plot ritrompate  
- tabel data: Tulisan pormat  

### 📈
- ** Tenderungan tengah *: Maksudna Π_32_, median Π_31_, modeu Π_30_  
- ** Sebaran ** : jangkauan Π_29_, varian Π_28_, simpangan standar Π_27_  
- ** Analisis ** : Laporan bubar Π_26_, IQR, normalisasi, transformasi kondisional  
- ** Deteksi embek ** : IQR sareng métode z-skor  

### manajemén file file
- penemuan pinter sareng `call()` Π_24_  
- Aktipkeun Aktivitas-format Π_23_  
- Manajemén database SQL sareng kelas Π_22_  
- Initionasi Π_21_  

### 🛠️ alat pamekar
- Sobah sistem Π_20_  
- Systax cek Π_19_  
- Kasalahan anu beunghar ngalaporkeun Π_18_  
- Sistem bantuan terpadu Π_17_  

### sacara internasional
- 100+ ditarjamahkeun  
- beban tarjamahan adat  
- Lumpus basa ngalihkeun deui Π_16_ `)  
- Automatic English fallback  

---

## Dependencies (handled automatically):

- pandas, numpy (data manipulation)

- matplotlib, seaborn (visualization)

- scikit-learn (statistics)

- sqlalchemy (database)

- geopandas (spatial data)

---

## 🔧 Usage Examples

### Set language 

**support for up to 131 languages** 
`1_14_:


### Statistik Dasar
Π_12_

### visualisasi
Π_11_

### File
Π_10_

### tarjamahan adat
Π_9_

### Synttax validasi
Π_8_

---

## 📂 Proyék Struktur

Π_7_

---

## 📜 License

Proyék ieu dilisensikeun handapeun ** MIT Π_4 _ ** .  
Tingali file Π_3_ kanggo detil.

---

## 🔮 jalan

- jinis visualisasi tambahan

- dukungan datar

- integrasi kénéh mesin

- Panganteur dumasar wéb

- Sistem plugin

---

⚡ siap super nooth transparan Π_1_ sareng ** pyatelper ** ? Mimitian ngajalajah ayeuna!